@@ -13,16 +13,27 @@ import (
 // AppName is used for command names.
 var AppName = "trdsql"
 
+// multiT is a flag for multiple queries.
+type multiT bool
+
+// multi is a flag for multiple queries.
+var multi = multiT(false)
+
+// EnableMultipleQueries enables multiple queries.
+func EnableMultipleQueries() {
+	multi = true
+}
+
 // TRDSQL represents DB definition and Importer/Exporter interface.
 type TRDSQL struct {
 	// Importer is interface of processing to
 	// import(create/insert) data.
 	Importer Importer
 	// Exporter is interface export to the process of
-	//  export(select) from the database.
+	// export(select) from the database.
 	Exporter Exporter
 
-	// Driver is database driver name(sqlite3/mysql/postgres).
+	// Driver is database driver name(sqlite3/sqlite/mysql/postgres).
 	Driver string
 	// Dsn is data source name.
 	Dsn string
@@ -100,6 +111,7 @@ const (
 	PSV
 )
 
+// String returns the string representation of the Format.
 func (f Format) String() string {
 	switch f {
 	case GUESS:
@@ -142,7 +154,7 @@ func (trd *TRDSQL) Exec(sql string) error {
 }
 
 // ExecContext is actually executed.
-func (trd *TRDSQL) ExecContext(ctx context.Context, sql string) error {
+func (trd *TRDSQL) ExecContext(ctx context.Context, sqlQuery string) error {
 	db, err := Connect(trd.Driver, trd.Dsn)
 	if err != nil {
 		return fmt.Errorf("connect: %w", err)
@@ -160,14 +172,14 @@ func (trd *TRDSQL) ExecContext(ctx context.Context, sql string) error {
 	}
 
 	if trd.Importer != nil {
-		sql, err = trd.Importer.ImportContext(ctx, db, sql)
+		sqlQuery, err = trd.Importer.ImportContext(ctx, db, sqlQuery)
 		if err != nil {
 			return fmt.Errorf("import: %w", err)
 		}
 	}
 
 	if trd.Exporter != nil {
-		if err := trd.Exporter.ExportContext(ctx, db, sql); err != nil {
+		if err := trd.Exporter.ExportContext(ctx, db, sqlQuery); err != nil {
 			return fmt.Errorf("export: %w", err)
 		}
 	}
